@@ -1,33 +1,36 @@
 from datetime import date
-from django.utils import six
 
-from django.db.models import signals
-from django.utils.encoding import force_bytes
-from django.utils.http import urlsafe_base64_encode
 from django.contrib.auth import get_user_model
-from django.contrib.auth.management import create_superuser
-from django.contrib.auth import models as auth_app
-
-from django.utils.http import int_to_base36, base36_to_int
-from django.utils.crypto import constant_time_compare, salted_hmac
-
-from django.template.loader import render_to_string
 from django.core.mail import EmailMultiAlternatives
+from django.db.models import signals
+from django.template.loader import render_to_string
+from django.utils import six
+from django.utils.crypto import constant_time_compare, salted_hmac
+from django.utils.encoding import force_bytes
+from django.utils.http import base36_to_int, int_to_base36
 
+from .compat import urlsafe_base64_encode
+from .conf import settings
 
 try:
     from django.contrib.sites.shortcuts import get_current_site
 except ImportError:
     from django.contrib.sites.models import get_current_site
 
-from .conf import settings
 
 if settings.USERS_CREATE_SUPERUSER:
-    # Prevent interactive question about wanting a superuser created.
-    signals.post_syncdb.disconnect(
-        create_superuser,
-        sender=auth_app,
-        dispatch_uid='django.contrib.auth.management.create_superuser')
+    try:
+        # create_superuser is removed in django 1.7
+        from django.contrib.auth.management import create_superuser
+    except ImportError:
+        pass
+    else:
+        # Prevent interactive question about wanting a superuser created.
+        from django.contrib.auth import models as auth_app
+        signals.post_syncdb.disconnect(
+            create_superuser,
+            sender=auth_app,
+            dispatch_uid='django.contrib.auth.management.create_superuser')
 
 
 def auto_create_superuser(sender, **kwargs):
